/**
 * @hidden
 */
export interface BaseProps {
    /**
     * Sets one of the two visually distinct types of progress bar.
     *
     * @hidden
     */
    type?: 'linear' | 'circular';
    /**
     * Sets the value of the progress bar. Has to be between `min` and `max` values. Defaults to `0`.
     * Set `null` to enable the indeterminate state of the progress bar.
     * See examples ([here]({% slug overview_progressbar %})).
     */
    value?: number | null;
    /**
     * The minimum value of the progress bar. Defaults to `0`.
     */
    min?: number;
    /**
     * The maximum value of the progress bar. Defaults to `100`.
     */
    max?: number;
    /**
     * Represents the `dir` HTML attribute. This is used to switch from LTR to RTL.
     */
    dir?: string;
    /**
     * The accessible label of the component.
     */
    ariaLabel?: string;
    /**
     * Sets the disabled state of the progress bar.
     * See examples ([here]({% slug progressbar_disabled %})).
     */
    disabled?: boolean;
    /**
     * Defines the orientation of the progress bar.
     * See examples ([here]({% slug progressbar_orientation %})) .
     * Defaults to `horizontal`.
     */
    orientation?: 'horizontal' | 'vertical' | string;
    /**
     * If set to `true`, the progress bar will be reversed.
     * See examples ([here]({% slug progressbar_direction %})).
     * Defaults to `false`.
     */
    reverse?: boolean;
    /**
     * Specifies a list of CSS classes that will be added to the progress bar element.
     */
    className?: string;
    /**
     * The styles that are applied to the inner element which represents the empty portion of the progress bar.
     * See examples ([here]({% slug progressbar_appearance %})).
     */
    emptyStyle?: object;
    /**
     * Sets additional classes to the inner element which represents the empty portion of the progress bar.
     * See examples ([here]({% slug progressbar_appearance %})).
     */
    emptyClassName?: string;
    /**
     * The styles that are applied to the inner element which represents the full portion of the progress bar.
     * See examples ([here]({% slug progressbar_appearance %})).
     */
    progressStyle?: object;
    /**
     * Sets additional classes to the inner element which represents the full portion of the progress bar.
     * See examples ([here]({% slug progressbar_appearance %})).
     */
    progressClassName?: string;
    /**
     * Sets the `tabIndex` property of the progress bar.
     */
    tabIndex?: number;
}
